Summary: Library of functions for manipulating TIFF format image files
Name: libtiff
Version: 4.0.6
Release: 1
License: BSD
Group: System Environment/Libraries
URL: http://www.libtiff.org/

Source0: ftp://ftp.remotesensing.org/pub/%{name}/tiff-%{version}.tar.gz
Source1: tiffconf.h
Source2: %{name}-3.9.5-aix32.so.3
Source3: %{name}-3.9.5-aix64.so.3
Source4: %{name}xx-3.9.5-aix32.so.3
Source5: %{name}xx-3.9.5-aix64.so.3

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires: make
BuildRequires: jbigkit-devel >= 2.1-1
BuildRequires: libjpeg-devel >= 9a-1
BuildRequires: xz-devel >= 5.2.2-1
BuildRequires: zlib-devel >= 1.2.3-7
Requires: jbigkit >= 2.1-1
Requires: libjpeg >= 9a-1
Requires: xz-libs >= 5.2.2-1
Requires: zlib >= 1.2.3-7

%description
The libtiff package contains a library of functions for manipulating
TIFF (Tagged Image File Format) image format files.  TIFF is a widely
used file format for bitmapped images.  TIFF files usually end in the
.tif extension and they are often quite large.

The libtiff package should be installed if you need to manipulate TIFF
format image files.

The library is available as 32-bit and 64-bit.


%package devel
Summary: Development tools for programs which will use the libtiff library
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires: jbigkit-devel >= 2.1-1
Requires: xz-devel >= 5.2.2-1

%description devel
This package contains the header files and documentation necessary for
developing programs which will manipulate TIFF format image files
using the libtiff library.

If you need to develop programs which will manipulate TIFF format
image files, you should install this package.  You'll also need to
install the libtiff package.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "xlc -q64" or "gcc -maix64".


%prep
export PATH=/opt/freeware/bin:$PATH
%setup -q -n tiff-%{version}


%build
export CONFIG_SHELL=/usr/bin/ksh
export CONFIG_ENV_ARGS=/usr/bin/ksh

# setup environment for 32-bit and 64-bit builds
export AR="ar -X32_64"
export NM="nm -X32_64"

# first build the 64-bit version
export CC="xlc -q64"
export CXX="xlC -q64"
./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --enable-shared --enable-static
gmake %{?_smp_mflags}

cp libtiff/.libs/libtiff.so.5 .
cp libtiff/.libs/libtiffxx.so.5 .
cp libtiff/tiffconf.h tiffconf-ppc64.h
gmake distclean

# now build the 32-bit version
export CC="xlc"
export CXX="xlC"
./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --enable-shared --enable-static
gmake %{?_smp_mflags}

cp libtiff/tiffconf.h tiffconf-ppc32.h


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}
gmake DESTDIR=${RPM_BUILD_ROOT} install

cp tiffconf-ppc??.h $RPM_BUILD_ROOT%{_includedir}/
cp %{SOURCE1} $RPM_BUILD_ROOT%{_includedir}/
chmod 644 $RPM_BUILD_ROOT%{_includedir}/*.h

/usr/bin/strip ${RPM_BUILD_ROOT}%{_bindir}/* || :

# setup environment for 32-bit and 64-bit builds
export AR="ar -X32_64"

# add the 64-bit shared objects to the shared library containing already the
# 32-bit shared objects
${AR} -q ${RPM_BUILD_ROOT}%{_libdir}/%{name}.a ./libtiff.so.5
${AR} -q ${RPM_BUILD_ROOT}%{_libdir}/%{name}xx.a ./libtiffxx.so.5

# add the version 3.9.x shared objects
# 32-bit shared objects
cp %{SOURCE2} libtiff.so.3
cp %{SOURCE4} libtiffxx.so.3
/usr/bin/strip -X32 -e libtiff.so.3 libtiffxx.so.3
${AR} -q ${RPM_BUILD_ROOT}%{_libdir}/%{name}.a ./libtiff.so.3
${AR} -q ${RPM_BUILD_ROOT}%{_libdir}/%{name}xx.a ./libtiffxx.so.3
# 64-bit shared objects
cp %{SOURCE3} libtiff.so.3
cp %{SOURCE5} libtiffxx.so.3
/usr/bin/strip -X64 -e libtiff.so.3 libtiffxx.so.3
${AR} -q ${RPM_BUILD_ROOT}%{_libdir}/%{name}.a ./libtiff.so.3
${AR} -q ${RPM_BUILD_ROOT}%{_libdir}/%{name}xx.a ./libtiffxx.so.3

# add AIX Toolbox compatibility members for compatibility with older apps
# (make sure they're set for LOADONLY with 'strip -e')
cp %{SOURCE2} shr.o
/usr/bin/strip -X32 -e shr.o
${AR} -q ${RPM_BUILD_ROOT}%{_libdir}/%{name}.a ./shr.o
cp %{SOURCE3} shr.o
/usr/bin/strip -X64 -e shr.o
${AR} -q ${RPM_BUILD_ROOT}%{_libdir}/%{name}.a ./shr.o

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system,-)
%doc COPYRIGHT README RELEASE-DATE VERSION
%{_bindir}/*
%{_libdir}/*.a
%{_mandir}/man1/*
/usr/bin/*
/usr/lib/*.a


%files devel
%defattr(-,root,system,-)
%doc TODO ChangeLog html
%{_includedir}/*
%{_libdir}/*.la
%{_mandir}/man3/*
/usr/include/*
/usr/lib/*.la


%changelog
* Fri Jan 01 2016 Michael Perzl <michael@perzl.org> - 4.0.6-1
- updated to version 4.0.6

* Fri Jan 01 2016 Michael Perzl <michael@perzl.org> - 4.0.5-1
- updated to version 4.0.5

* Fri Jan 01 2016 Michael Perzl <michael@perzl.org> - 4.0.4-1
- updated to version 4.0.4

* Sun Sep 23 2012 Michael Perzl <michael@perzl.org> - 4.0.3-1
- updated to version 4.0.3

* Wed Jul 18 2012 Michael Perzl <michael@perzl.org> - 4.0.2-1
- updated to version 4.0.2

* Tue Apr 24 2012 Michael Perzl <michael@perzl.org> - 4.0.1-3
- added missing dependency on 'xz-libs'

* Thu Mar 15 2012 Michael Perzl <michael@perzl.org> - 4.0.1-2
- added missing dependency on 'xz-libs'

* Sun Feb 19 2012 Michael Perzl <michael@perzl.org> - 4.0.1-1
- updated to version 4.0.1

* Thu Dec 22 2011 Michael Perzl <michael@perzl.org> - 4.0.0-1
- updated to version 4.0.0

* Thu Dec 22 2011 Michael Perzl <michael@perzl.org> - 3.9.5-2
- added missing 64-bit libtiffxx.so.3 shared object

* Tue Apr 12 2011 Michael Perzl <michael@perzl.org> - 3.9.5-1
- updated to version 3.9.5

* Tue Oct 26 2010 Michael Perzl <michael@perzl.org> - 3.9.4-2
- fixed a compile issue when including tiffio.h

* Wed Jun 16 2010 Michael Perzl <michael@perzl.org> - 3.9.4-1
- updated to version 3.9.4

* Mon Jun 14 2010 Michael Perzl <michael@perzl.org> - 3.9.3-1
- updated to version 3.9.3

* Tue Jan 19 2010 Michael Perzl <michael@perzl.org> - 3.9.2-2
- fixed a spec file dependency

* Thu Nov 05 2009 Michael Perzl <michael@perzl.org> - 3.9.2-1
- updated to version 3.9.2
- fixed AIX Toolbox compatibility issues

* Mon Aug 31 2009 Michael Perzl <michael@perzl.org> - 3.9.1-1
- updated to version 3.9.1

* Wed Aug 26 2009 Michael Perzl <michael@perzl.org> - 3.9.0-1
- updated to version 3.9.0

* Sat Mar 22 2008 Michael Perzl <michael@perzl.org> - 3.8.2-1
- first version for AIX V5.1 and higher
